==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/zh_HK.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "星期日",
    "Monday" : "星期一",
    "Tuesday" : "星期二",
    "Wednesday" : "星期三",
    "Thursday" : "星期四",
    "Friday" : "星期五",
    "Saturday" : "星期六",
    "January" : "一月",
    "February" : "二月",
    "March" : "三月",
    "April" : "四月",
    "May" : "五月",
    "June" : "六月",
    "July" : "七月",
    "August" : "八月",
    "September" : "九月",
    "October" : "十月",
    "November" : "十一月",
    "December" : "十二月",
    "Settings" : "設定",
    "Saving..." : "儲存中...",
    "seconds ago" : "秒前",
    "No" : "否",
    "Yes" : "是",
    "Ok" : "確認",
    "Cancel" : "取消",
    "Continue" : "繼續",
    "Shared" : "已分享",
    "Error" : "錯誤",
    "Error while sharing" : "分享時發生錯誤",
    "Error while unsharing" : "取消分享時發生錯誤",
    "Error while changing permissions" : "更改權限時發生錯誤",
    "Set expiration date" : "設定分享期限",
    "Expiration date" : "分享期限",
    "Sending ..." : "發送中...",
    "Email sent" : "郵件已傳",
    "Share link" : "分享連結",
    "Password protect" : "密碼保護",
    "Password" : "密碼",
    "Send" : "傳送",
    "Shared with you and the group {group} by {owner}" : "{owner}與你及群組的分享",
    "Shared with you by {owner}" : "{owner}與你的分享",
    "Unshare" : "取消分享",
    "create" : "新增",
    "delete" : "刪除",
    "Share" : "分享",
    "Warning" : "警告",
    "Delete" : "刪除",
    "Add" : "加入",
    "The update was successful. Redirecting you to ownCloud now." : "更新成功, 正",
    "Use the following link to reset your password: {link}" : "請用以下連結重設你的密碼: {link}",
    "New password" : "新密碼",
    "New Password" : "新密碼",
    "Reset password" : "重設密碼",
    "Personal" : "個人",
    "Users" : "用戶",
    "Apps" : "軟件",
    "Admin" : "管理",
    "Help" : "幫助",
    "Create an <strong>admin account</strong>" : "建立管理員帳戶",
    "Username" : "用戶名稱",
    "Configure the database" : "設定資料庫",
    "Database user" : "資料庫帳戶",
    "Database password" : "資料庫密碼",
    "Database name" : "資料庫名稱",
    "Log out" : "登出",
    "Search" : "尋找",
    "Log in" : "登入",
    "remember" : "記住"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/zh_HK.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "星期日",
    "Monday" : "星期一",
    "Tuesday" : "星期二",
    "Wednesday" : "星期三",
    "Thursday" : "星期四",
    "Friday" : "星期五",
    "Saturday" : "星期六",
    "January" : "一月",
    "February" : "二月",
    "March" : "三月",
    "April" : "四月",
    "May" : "五月",
    "June" : "六月",
    "July" : "七月",
    "August" : "八月",
    "September" : "九月",
    "October" : "十月",
    "November" : "十一月",
    "December" : "十二月",
    "Settings" : "設定",
    "Saving..." : "儲存中...",
    "seconds ago" : "秒前",
    "No" : "否",
    "Yes" : "是",
    "Ok" : "確認",
    "Cancel" : "取消",
    "Continue" : "繼續",
    "Shared" : "已分享",
    "Error" : "錯誤",
    "Error while sharing" : "分享時發生錯誤",
    "Error while unsharing" : "取消分享時發生錯誤",
    "Set expiration date" : "設定分享期限",
    "Expiration date" : "分享期限",
    "Sending ..." : "發送中...",
    "Email sent" : "郵件已傳",
    "Share link" : "分享連結",
    "Password protect" : "密碼保護",
    "Password" : "密碼",
    "Send" : "傳送",
    "Shared with you and the group {group} by {owner}" : "{owner}與你及群組的分享",
    "Shared with you by {owner}" : "{owner}與你的分享",
    "Unshare" : "取消分享",
    "create" : "新增",
    "delete" : "刪除",
    "Share" : "分享",
    "Warning" : "警告",
    "Delete" : "刪除",
    "Rename" : "重新命名",
    "Add" : "加入",
    "The update was successful. Redirecting you to ownCloud now." : "更新成功, 正",
    "Personal" : "個人",
    "Users" : "用戶",
    "Apps" : "軟件",
    "Admin" : "管理",
    "Help" : "幫助",
    "Create an <strong>admin account</strong>" : "建立管理員帳戶",
    "Username" : "用戶名稱",
    "Configure the database" : "設定資料庫",
    "Database user" : "資料庫帳戶",
    "Database password" : "資料庫密碼",
    "Database name" : "資料庫名稱",
    "Log out" : "登出",
    "Search" : "尋找",
    "Log in" : "登入",
    "Use the following link to reset your password: {link}" : "請用以下連結重設你的密碼: {link}",
    "New password" : "新密碼",
    "New Password" : "新密碼",
    "Reset password" : "重設密碼"
},
"nplurals=1; plural=0;");
